@@ -47,7 +47,7 @@ class AgentAuditedClient(AbstractModel):
         :type ThisMonthAmt: int
         :param HasOverdueBill: 是否欠费,0：不欠费；1：欠费
         :type HasOverdueBill: int
-        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量已关联)/old_newchecking(存量-新关联考核中)/old_newnotpass(存量-新关联未达标)/direct(直销)/direct_newopp(直销(新商机))/空
+        :param ClientType: 客户类型：可以为new(自拓)/assign(指派)/old(官网)/direct(直销)/direct_newopp(直销(新商机))/空
         :type ClientType: str
         :param ProjectType: 项目类型：可以为self(自拓项目)/platform(合作项目)/repeat(复算项目  )/空
         :type ProjectType: str
@@ -132,7 +132,7 @@ class AgentBillElem(AbstractModel):
         :type Amt: int
         :param PayerMode: agentpay：代付；selfpay：自付
         :type PayerMode: str
-        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量)/空
+        :param ClientType: 客户类型：可以为new(自拓)/assign(指定)/old(官网)/direct(直销)/direct_newopp(直销(新商机))/空
 注意：此字段可能返回 null，表示取不到有效值。
         :type ClientType: str
         :param ProjectType: 项目类型：可以为self(自拓项目)/platform(合作项目)/repeat(复算项目  )/空
@@ -254,9 +254,9 @@ class AgentDealElem(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DealId: 订单自增 ID
+        :param DealId: 订单自增 ID【请勿依赖该字段作为唯一标识】
         :type DealId: str
-        :param DealName: 订单号
+        :param DealName: 订单号【订单唯一键】
         :type DealName: str
         :param GoodsCategoryId: 商品类型 ID
         :type GoodsCategoryId: str
@@ -307,7 +307,7 @@ class AgentDealElem(AbstractModel):
         :param BigDealId: 大订单号
 注意：此字段可能返回 null，表示取不到有效值。
         :type BigDealId: str
-        :param ClientType: 客户类型（new：新拓；old：存量；assign：指派）
+        :param ClientType: 客户类型（new：自拓；old：官网；assign：指派；direct：直销；direct_newopp：直销(新商机)）
 注意：此字段可能返回 null，表示取不到有效值。
         :type ClientType: str
         :param ProjectType: 项目类型（self：自拓；repeat：直销；platform：官网合作）
@@ -417,9 +417,9 @@ class AgentDealNewElem(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DealId: 订单自增 ID
+        :param DealId: 订单自增 ID【请勿依赖该字段作为唯一标识】
         :type DealId: str
-        :param DealName: 订单号
+        :param DealName: 订单号【订单唯一键】
         :type DealName: str
         :param GoodsCategoryId: 商品类型 ID
         :type GoodsCategoryId: str
@@ -470,7 +470,7 @@ class AgentDealNewElem(AbstractModel):
         :param BigDealId: 大订单号
 注意：此字段可能返回 null，表示取不到有效值。
         :type BigDealId: str
-        :param ClientType: 客户类型（new：新拓；old：存量；assign：指派）
+        :param ClientType: 客户类型（new：自拓；old：官网；assign：指派；direct：直销；direct_newopp：直销(新商机)）
 注意：此字段可能返回 null，表示取不到有效值。
         :type ClientType: str
         :param ProjectType: 项目类型（self：自拓；repeat：直销；platform：官网合作）
